<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ro" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Despre</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Pornește torrentul</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Omite verificarea indexului</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Creează subdosar</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Toate</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Necategorisite</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Adăugare categorie...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Elimină categoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Elimină categoriile neutilizate</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Reia torentele</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Suspendă torentele</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Șterge torentele</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit category...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Închide qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Doar o legătură per linie</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Limita ratei de încărcare globală trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Limita ratei de descărcare globală trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Limita ratei de încărcare alternativă trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Limita ratei de descărcare alternative trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Numărul maxim de descărcări active trebuie să fie mai mare decât -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Numărul maxim de încărcări active trebuie să fie mai mare decât -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Numărul maxim de torrente active trebuie să fie mai mare decât -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Limita maximă a numărului de conexiuni trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limita maximă a numărului de conexiuni pe torrent trebuie să fie mai mare ca 0 sau dezactivată.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Numărul maxim de sloturi de încărcare pe torrent trebuie să fie mai mare ca 0 sau dezactivat.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nu se pot salva preferințele programului, probabil qBittorrent nu poate fi contactat.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent pe Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Necunoscut</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Limita raportului de partajare trebuie să fie între 0 și 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Portul folosit pentru conexiunile de intrare trebuie să fie între 1 și 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Portul folosit pentru interfața Web trebuie să fie între 1 și 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Nu se poate autentifica, probabil qBittorrent nu poate fi contactat.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Numele de utilizator sau parola nu sunt valide.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nume de utilizator</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parolă</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Autentifică</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autori originali</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplică</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Încărcare torente</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Salvează fișierele în locația:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Fișier cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Introduceți dosarul aici</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mai multe informații</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informații despre certificate</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Stabilire locație</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Limit download rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Altul...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Luni</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Marți</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Miercuri</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Joi</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Vineri</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sâmbătă</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Duminică</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Deautentifică</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Descarcă torrente de la adrese URL sau legături magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Încărcare torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Sigur doriți să ștergeți torrentele selectate din lista de transferuri?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvează</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Clientul qBittorrent nu poate fi contactat</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Free space: %1</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name cannot be empty</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name is unchanged</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Failed to update name</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editare</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Unelte</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fișier</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vizualizare</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opțiuni...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Reluare</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Bara de unelte superioară</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Bara de stare</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Viteza în bara de titlu</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Donați!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Reia toate</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistici</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Suspendă toate</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Adăugare fișier torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentație</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Adăugare legătură torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nu</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Limită viteză de încărcare globală</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Limită viteză de descărare globală</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Sigur doriți să închideți qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1/s, Î: %2/s] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Your browser does not support this feature</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opțiuni</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descărcări</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexiune</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfață Web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Limbă</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Limba interfeței cu utilizatorul:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrare adrese IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interfață utilizator Web (Control la distanță)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domenii servitor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Utilizează HTTPS în locul HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Păstrează torentele incomplete în:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copiază fișierele .torrent în:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copiază fișierele .torrent pentru descărcările încheiate în:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pre-alocă spațiu pe disc pentru toate fișierele</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Adaugă extensia .!qB fișierelor incomplete</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Adaugă automat torente din:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servitor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Servitorul necesită o conexiune securizată (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentificare</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nume utilizator:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parolă:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocol activat:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP și μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port ascultat</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Portul utilizat pentru conexiunile de intrare:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Utilizează înaintare port UPnP / NAT-PMP de la routerul meu</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Utilizează port diferit la fiecare pornire</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Stabilește limitele conexiunii</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Numărul maxim de conexiuni per torent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Număr maxim global de conexiuni:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Numărul maxim de sloturi de încărcare per torent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Număr maxim global de sloturi de încărcare:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servitor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Niciunul)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Gazdă:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Utilizează proxy pentru conexiuni la parteneri</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Utilizează proxy doar pentru torrente</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Cale filtru (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Adrese IP blocate manual...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplică urmăritoarelor</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limite de viteză globale</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Încărcare:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Descărcare:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Limite de viteză alternative</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>De la:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>la:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Când:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Zilnic</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Zile lucrătoare</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Zile libere</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Setări limite de viteză</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplică limitarea de viteză incluzând datele de transport</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplică limitarea ratei protocolului µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Confidențialitate</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Activează rețeaua descentralizată (DHT) pentru a găsi mai multe surse</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Activează schimbul de surse (PeX) cu alți clienți pentru a găsi mai multe surse</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Activează descoperirea partenerilor locali pentru a găsi mai mulți parteneri</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modul criptării:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Necesită criptarea</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Dezactivează criptarea</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Activează modul anonim</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Numărul maxim de descărcări active:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Numărul maxim de încărcări active:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Numărul maxim de torrente active:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Nu socoti torrentele lente în aceste limite</translation>
    </message>
    <message>
        <source>then</source>
        <translation>apoi</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Utilizează UPnP / NAT-PMP pentru a înainta portul din routerul meu</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Cheie:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Înregistrează</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nume de domeniu:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parametri sprijiniți (sensibil la majuscule):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nume torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Categorie</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Cale conținut (aceeași cu calea rădăcină pentru torrent cu mai multe fișiere)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Cale rădăcină (cale subdirector a primului torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Cale de salvare</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Număr de fișiere</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Dimensiune torrent (octeți)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Urmăritor actual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Informații indexare</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Sfat: Încapsulați parametrul între ghilimele (englezești) pentru a evita ca textul să fie tăiat la spațiu (de ex., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Numele de utilizator al interfeței Web trebuie să conțină minim 3 caractere.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Parola interfeței Web trebuie să fie de minim 6 caractere.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>sec</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries (GeoIP):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listen on IPv6 address (requires restart):</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Indicatori</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexiune</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Client</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progres</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Viteză descărcare</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Viteză încărcare</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Descărcat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Încărcat</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevanță</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fișiere</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Țară</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normală</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Înaltă</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximă</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Urmăritoare</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Parteneri</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Surse HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Conținut</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Descărcat:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfer</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Timp activ:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Timp rămas:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Încărcat:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Surse:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Viteză de descărcare:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Viteză de încărcare:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Parteneri:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limită de descărcare:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limită de încărcare:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Pierdut:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Conexiuni:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informații</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentariu:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Raport de partajare:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Reanunțare în:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Văzut complet ultima dată:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Dimensiune totală:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Bucăți:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creat de:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Adăugat la:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Terminat la:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creat la:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Index torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Cale de salvare:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Niciodată</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (avem %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 în această sesiune)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maxim)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 în total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 în medie)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Dosar urmărit</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Suprascrie locația pentru salvare</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Dosar urmărit</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Cale de salvare implicită</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiO/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistici</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistici utilizator</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistici prestocare (cache)</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Accesări prestocare citire:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Timp mediu la coadă:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistici performanță</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Sarcini Intrare/Ieșire puse la coadă:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Supraîncărcare prestocare scriere:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Supraîncărcare prestocare citire:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Dimensiune totală coadă:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 noduri</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Toate (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Se descarcă (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Se contribuie (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Încheiate (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Reluate (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Suspendate (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Active (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactive (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Cu erori (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Toate (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Se descarcă (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Se contribuie (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Încheiate (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Suspendate (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Reluate (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Active (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactive (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Cu erori (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Gata</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Surse</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Parteneri</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Viteză descărcare</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Viteză încărcare</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Raport</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Timp rămas</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etichete</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Adăugat la</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Terminat la</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Urmăritor</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limită descărcare</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limită încărcare</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Descărcat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Încărcat</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Descărcat în sesiune</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Încărcat în sesiune</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Rămas</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Timp activ</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Cale salvare</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Terminat</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limită raport</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Văzut complet ultima dată</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Ultima activitate</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Dimensiune totală</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Parteneri</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesaj</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dialog adăugare urmăritoare</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Listă urmăritoare de adăugat (unul per linie):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 în urmă</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorii</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitare viteză descărcare torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitare viteză de încărcare torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Redenumire</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Reia</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forțează reluarea</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Suspendă</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Șterge</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limitare raport de partajare....</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limitare viteză de încărcare...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limitare viteză de descărcare...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mută mai sus</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mută mai jos</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mută în vârf</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mută la bază</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Stabilire locație...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Descarcă prima și ultima bucată întâi</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Administrare automată torente</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nouă...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Restabilește</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forțează reverificarea</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mod super-contribuire</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Redenumire...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Descarcă în ordine secvențială</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitare raport încărcare/descărcare torrent</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Utilizează limitarea globală a partajării</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nu stabili nicio limită de partajare</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Stabilește limita de partajare la</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>raport</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minute</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmare ștergere</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Șterge și fișierele de pe disc</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Descarcă de la adrese URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarcă</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>O</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiO</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiO</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiO</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiO</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiO</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiO</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1o %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1z %2o</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Necunoscut</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tag:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Current maintainer</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Special Thanks</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Libraries</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv6 addresses</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All IPv4 addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TorrentContentTreeView</name>
    <message>
        <source>Renaming</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name:</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>